@@ -4,8 +4,8 @@
 #       Github: https://github.com/thieu1995        %
 # --------------------------------------------------%
 
-import numpy as np
 from permetrics.evaluator import Evaluator
+import numpy as np
 
 
 class ClassificationMetric(Evaluator):
@@ -29,7 +29,7 @@ class ClassificationMetric(Evaluator):
         if kwargs is None: kwargs = {}
         self.set_keyword_arguments(kwargs)
 
-    def mean_log_likelihood(self, y_true=None, y_pred=None, multi_output="raw_values", decimal=None, clean=True, positive_only=True):
+    def mean_log_likelihood(self, y_true=None, y_pred=None, multi_output="raw_values", decimal=None, non_zero=True, positive=True):
         """
         Mean Log Likelihood (MLL): Best possible score is ..., the higher value is better. Range = (-inf, +inf)
 
@@ -40,39 +40,47 @@ class ClassificationMetric(Evaluator):
             y_pred (tuple, list, np.ndarray): The prediction values
             multi_output: Can be "raw_values" or list weights of variables such as [0.5, 0.2, 0.3] for 3 columns, (Optional, default = "raw_values")
             decimal (int): The number of fractional parts after the decimal point (Optional, default = 5)
-            clean (bool): Remove all rows contain 0 value in y_pred (some methods have denominator is y_pred) (Optional, default = True)
-            positive_only (bool): Calculate metric based on positive values only or not (Optional, default = True)
+            non_zero (bool): Remove all rows contain 0 value in y_pred (some methods have denominator is y_pred) (Optional, default = True)
+            positive (bool): Calculate metric based on positive values only or not (Optional, default = True)
 
         Returns:
             result (float, int, np.ndarray): MLL metric
         """
-        y_true, y_pred, one_dim, decimal = self.get_preprocessed_data(y_true, y_pred, clean, decimal, positive_only)
+        y_true, y_pred, one_dim, decimal = self.get_processed_data(y_true, y_pred, decimal)
+        if non_zero:
+            y_true, y_pred = self.get_non_zero_data(y_true, y_pred, one_dim, 1)
+        else:
+            y_pred[y_pred == 0] = self.EPSILON
+        y_true, y_pred = self.get_positive_data(y_true, y_pred, one_dim, 2)
         if one_dim:
             return np.round(np.mean(-(y_true * np.log(y_pred) + (1 - y_true) * np.log(1 - y_pred))), decimal)
         else:
             result = np.mean(-(y_true * np.log(y_pred) + (1 - y_true) * np.log(1 - y_pred)), axis=0)
             return self.get_multi_output_result(result, multi_output, decimal)
 
-    def single_log_likelihood(self, y_true=None, y_pred=None, decimal=None, clean=True, positive_only=True):
+    def single_log_likelihood(self, y_true=None, y_pred=None, decimal=None, non_zero=True, positive=True):
         """
         Log Likelihood (LL): Best possible score is ..., the higher value is better. Range = (-inf, +inf)
 
-        Notes
-        ~~~~~
-            + Computes the log likelihood between two numbers, or for element between a pair of list, tuple or numpy arrays.
+        Note: Computes the log likelihood between two numbers, or for element between a pair of list, tuple or numpy arrays.
 
         Args:
             y_true (tuple, list, np.ndarray): The ground truth values
             y_pred (tuple, list, np.ndarray): The prediction values
             multi_output: Can be "raw_values" or list weights of variables such as [0.5, 0.2, 0.3] for 3 columns, (Optional, default = "raw_values")
             decimal (int): The number of fractional parts after the decimal point (Optional, default = 5)
-            clean (bool): Remove all rows contain 0 value in y_pred (some methods have denominator is y_pred) (Optional, default = True)
-            positive_only (bool): Calculate metric based on positive values only or not (Optional, default = True)
+            non_zero (bool): Remove all rows contain 0 value in y_pred (some methods have denominator is y_pred) (Optional, default = True)
+            positive (bool): Calculate metric based on positive values only or not (Optional, default = True)
 
         Returns:
             result (float, int, np.ndarray): LL metric
         """
-        y_true, y_pred, one_dim, decimal = self.get_preprocessed_data(y_true, y_pred, clean, decimal, positive_only)
+        y_true, y_pred, one_dim, decimal = self.get_processed_data(y_true, y_pred, decimal)
+        if non_zero:
+            y_true, y_pred = self.get_non_zero_data(y_true, y_pred, one_dim, 1)
+        else:
+            y_pred[y_pred == 0] = self.EPSILON
+        y_true, y_pred = self.get_positive_data(y_true, y_pred, one_dim, 2)
         return np.round(-(y_true * np.log(y_pred) + (1 - y_true) * np.log(1 - y_pred)), decimal)
 
     MLL = mll = mean_log_likelihood
